fatal constant
LogLevel
const fatal
FATAL
This log level is used to indicate critical errors that could cause the system or program to fail or crash.
Implementation
static const LogLevel fatal = LogLevel._('fatal', 7);